==> was-plugin-extensions-3.8.0-sources.jar: com/xebialabs/deployit/community/wasext/step/ManagedWebServerPluginConfigurationCopyStep.java <==
package com.xebialabs.deployit.community.wasext.step;

import static com.google.common.base.Preconditions.checkNotNull;
import static com.google.common.io.Closeables.closeQuietly;
import static com.xebialabs.overthere.util.OverthereFileCopier.copy;
import static java.lang.String.format;

import com.xebialabs.deployit.plugin.api.deployment.execution.DeploymentExecutionContext;
import com.xebialabs.deployit.plugin.api.deployment.execution.DeploymentStep;
import com.xebialabs.deployit.plugin.overthere.Host;
import com.xebialabs.deployit.plugin.was.container.ManagedWebServer;
import com.xebialabs.deployit.plugin.was.container.Node;
import com.xebialabs.overthere.OverthereConnection;
import com.xebialabs.overthere.OverthereFile;

@SuppressWarnings("serial")
public class ManagedWebServerPluginConfigurationCopyStep implements DeploymentStep {
    private final int order;
    private final String description;
    private final Host srcHost;
    private final Host targetHost;
    private final String pluginSrcFilePath;
    private final String pluginDestFilePath;

    public ManagedWebServerPluginConfigurationCopyStep(int order, ManagedWebServer webserver) {
        this.order = order;
        Node webserverNode = webserver.getNode();
        srcHost = webserverNode.getCell().getCellHost();
        targetHost = webserver.getProperty("host");
        pluginSrcFilePath = format("%s/config/cells/%s/nodes/%s/servers/%s/plugin-cfg.xml",
                webserverNode.getCell().getWasHome(), webserverNode.getCellName(),
                webserverNode.getNodeName(), webserver.getName().trim());
        pluginDestFilePath = checkNotNull(webserver.<String>getProperty("pluginConfigurationPath"), "pluginConfigurationPath");
        description = format("Copy WebSphere plugin configuration file directly to '%s' for unmanaged webserver '%s'",
                targetHost.getName(), webserver.getName());
    }

    @Override
    public String getDescription() {
        return description;
    }

    @Override
    public Result execute(DeploymentExecutionContext ctx) throws Exception {
        OverthereConnection srcHostConnection = srcHost.getConnection();
        OverthereConnection targetHostConnection = targetHost.getConnection();
        try {
            final OverthereFile source = srcHostConnection.getFile(pluginSrcFilePath);
            final OverthereFile remote = targetHostConnection.getFile(pluginDestFilePath);
            ctx.logOutput(format("Copying generated plugin configuration file from '%s' on '%s' to '%s' on '%s'",
                    pluginSrcFilePath, srcHost, pluginDestFilePath, targetHost));
            copy(source, remote);
        } finally {
            closeQuietly(srcHostConnection);
            closeQuietly(targetHostConnection);
        }
        return Result.Success;
    }

    @Override
    public int getOrder() {
        return order;
    }
}

==> was-plugin-extensions-4.0.0-sources.jar: com/xebialabs/deployit/community/wasext/step/ManagedWebServerPluginConfigurationCopyStep.java <==
package com.xebialabs.deployit.community.wasext.step;

import com.xebialabs.deployit.community.wasext.util.Closeables;
import com.xebialabs.deployit.plugin.api.deployment.execution.DeploymentExecutionContext;
import com.xebialabs.deployit.plugin.api.deployment.execution.DeploymentStep;
import com.xebialabs.deployit.plugin.overthere.Host;
import com.xebialabs.deployit.plugin.was.container.ManagedWebServer;
import com.xebialabs.deployit.plugin.was.container.Node;
import com.xebialabs.overthere.OverthereConnection;
import com.xebialabs.overthere.OverthereFile;

import static com.google.common.base.Preconditions.checkNotNull;
import static com.xebialabs.overthere.util.OverthereFileCopier.copy;
import static java.lang.String.format;

@SuppressWarnings("serial")
public class ManagedWebServerPluginConfigurationCopyStep implements DeploymentStep {
    private final int order;
    private final String description;
    private final Host srcHost;
    private final Host targetHost;
    private final String pluginSrcFilePath;
    private final String pluginDestFilePath;

    public ManagedWebServerPluginConfigurationCopyStep(int order, ManagedWebServer webserver) {
        this.order = order;
        Node webserverNode = webserver.getNode();
        srcHost = webserverNode.getCell().getCellHost();
        targetHost = webserver.getProperty("host");
        pluginSrcFilePath = format("%s/config/cells/%s/nodes/%s/servers/%s/plugin-cfg.xml",
                webserverNode.getCell().getWasHome(), webserverNode.getCellName(),
                webserverNode.getNodeName(), webserver.getName().trim());
        pluginDestFilePath = checkNotNull(webserver.<String>getProperty("pluginConfigurationPath"), "pluginConfigurationPath");
        description = format("Copy WebSphere plugin configuration file directly to '%s' for unmanaged webserver '%s'",
                targetHost.getName(), webserver.getName());
    }

    @Override
    public String getDescription() {
        return description;
    }

    @Override
    public Result execute(DeploymentExecutionContext ctx) throws Exception {
        OverthereConnection srcHostConnection = srcHost.getConnection();
        OverthereConnection targetHostConnection = targetHost.getConnection();
        try {
            final OverthereFile source = srcHostConnection.getFile(pluginSrcFilePath);
            final OverthereFile remote = targetHostConnection.getFile(pluginDestFilePath);
            ctx.logOutput(format("Copying generated plugin configuration file from '%s' on '%s' to '%s' on '%s'",
                    pluginSrcFilePath, srcHost, pluginDestFilePath, targetHost));
            copy(source, remote);
        } finally {
            Closeables.closeQuietly(srcHostConnection);
            Closeables.closeQuietly(targetHostConnection);
        }
        return Result.Success;
    }

    @Override
    public int getOrder() {
        return order;
    }
}
